# extracted from sip.h, SIP_API_MAJOR_NR SIP_API_MINOR_NR defines
%define _sip_api_major 12
%define _sip_api_minor 7
%define _sip_api       %{_sip_api_major}.%{_sip_api_minor}

Name:           python-sip
Version:        4.19.25
Release:        %mkrel 2
Summary:        SIP - Python/C++ Bindings Generator
License:        GPLv2+
Group:          Development/Python
URL:            http://www.riverbankcomputing.co.uk/software/sip/intro
Source0:        https://www.riverbankcomputing.com/static/Downloads/sip/%{version}/sip-%{version}.tar.gz
Patch50:        sip-4.18-no_strip.patch
Patch53:        sip-4.19.18-no_hardcode_sip_so.patch
BuildRequires:  pkgconfig(bzip2)

%description
SIP is a tool that makes it very easy to create Python bindings for C and C++
libraries.
It was originally developed to create PyQt, the Python bindings for the Qt
toolkit, but can be used to create bindings for any C or C++ library.

#------------------------------------------------------------
### Python3 ###

%package -n     python3-sip
Summary:        SIP - Python 3/C++ Bindings Generator
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
Provides:       python3-sip-api(%{_sip_api_major}) = %{_sip_api}
Requires: sip

%description -n python3-sip
This is the Python 3 build of SIP.

SIP is a tool for generating bindings for C++ classes so that they can be
accessed as normal Python 3 classes. SIP takes many of its ideas from SWIG but,
because it is specifically designed for C++ and Python, is able to generate
tighter bindings. SIP is so called because it is a small SWIG.

SIP was originally designed to generate Python bindings for KDE and so has
explicit support for the signal slot mechanism used by the Qt/KDE class
libraries. However, SIP can be used to generate Python 3 bindings for any C++
class library.

%files -n python3-sip
%{python3_sitearch}/sip.so
%{python3_sitearch}/sip*.py*
%{python3_sitearch}/sip-%{version}.dist-info/

#------------------------------------------------------------

%package -n     python3-sip-devel
Summary:        Files needed to generate Python 3 bindings for any C++ class library
Group:          Development/Python
Requires:       python3-sip = %{version}
Requires:       pkgconfig(python3)

%description -n python3-sip-devel
This package contains files needed to generate Python 3 bindings for any C++
classes library.

%files -n python3-sip-devel
%{_datadir}/python3-sip/
%{_includedir}/python%{python3_version}m/*

#------------------------------------------------------------

%package -n     python3-pyqt4-sip
Summary:        SIP - Python 3/C++ Bindings Generator for pyqt4
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
Provides:       python3-pyqt4-sip-api(%{_sip_api_major}) = %{_sip_api}

%description -n python3-pyqt4-sip
This is the Python 3 build of pyqt4-SIP.

SIP is a tool for generating bindings for C++ classes so that they can be
accessed as normal Python 3 classes. SIP takes many of its ideas from SWIG but,
because it is specifically designed for C++ and Python, is able to generate
tighter bindings. SIP is so called because it is a small SWIG.

SIP was originally designed to generate Python bindings for KDE and so has
explicit support for the signal slot mechanism used by the Qt/KDE class
libraries. However, SIP can be used to generate Python 3 bindings for any C++
class library.

%files -n python3-pyqt4-sip
%{python3_sitearch}/PyQt4/sip.*
%{python3_sitearch}/PyQt4_sip-%{version}.dist-info/

#------------------------------------------------------------

%package -n     python3-pyqt5-sip
Summary:        SIP - Python 3/C++ Bindings Generator for pyqt5
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
Provides:       python3-pyqt5-sip-api(%{_sip_api_major}) = %{_sip_api}

%description -n python3-pyqt5-sip
This is the Python 3 build of pyqt5-SIP.

SIP is a tool for generating bindings for C++ classes so that they can be
accessed as normal Python 3 classes. SIP takes many of its ideas from SWIG but,
because it is specifically designed for C++ and Python, is able to generate
tighter bindings. SIP is so called because it is a small SWIG.

SIP was originally designed to generate Python bindings for KDE and so has
explicit support for the signal slot mechanism used by the Qt/KDE class
libraries. However, SIP can be used to generate Python 3 bindings for any C++
class library.

%files -n python3-pyqt5-sip
%{python3_sitearch}/PyQt5/sip.*
%{python3_sitearch}/PyQt5_sip-%{version}.dist-info/

#------------------------------------------------------------

%package -n     python3-wx-siplib
Summary:        SIP - Python 3/C++ Bindings Generator for wx
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
Provides:       python3-wx-siplib-api(%{_sip_api_major}) = %{_sip_api}

%description -n python3-wx-siplib
This is the Python 3 build of wx-siplib.

SIP is a tool for generating bindings for C++ classes so that they can be
accessed as normal Python 3 classes. SIP takes many of its ideas from SWIG but,
because it is specifically designed for C++ and Python, is able to generate
tighter bindings. SIP is so called because it is a small SWIG.

SIP was originally designed to generate Python bindings for KDE and so has
explicit support for the signal slot mechanism used by the Qt/KDE class
libraries. However, SIP can be used to generate Python 3 bindings for any C++
class library.

%files -n python3-wx-siplib
%dir %{python3_sitearch}/wx/
%{python3_sitearch}/wx/siplib.*
%{python3_sitearch}/wx_siplib-%{version}.dist-info/

#------------------------------------------------------------

%prep
%setup -q -n sip-%{version}
%apply_patches
export real_api_major=`grep SIP_API_MAJOR_NR siplib/sip.h|head -n1|awk -F' ' '{print $3}'`
export real_api_minor=`grep SIP_API_MINOR_NR siplib/sip.h|head -n1|awk -F' ' '{print $3}'`
if [ $real_api_major -ne %{_sip_api_major} ]; then
	echo 'Wrong spi major specified: Should be' $real_api_major ', but set' %{_sip_api_major}
	exit 1
fi
if [ $real_api_minor -ne %{_sip_api_minor} ]; then
	echo 'Wrong spi minor specified: Should be' $real_api_minor ', but set' %{_sip_api_minor}
	exit 1
fi

#  Don't use X11R6 prefix for includes neither libraries by default.
for file in specs/linux-*; do
    perl -p -i -e "s@/X11R6/@/@g" $file
done

%build
### Python3 ###
mkdir python3-sip
pushd python3-sip
%{__python3} ../configure.py \
             --sipdir=%{_datadir}/python3-sip \
             CXXFLAGS+="%{optflags}" \
             CFLAGS+="%{optflags}" \
             LFLAGS+="%{ldflags}" \
             LIBS="%{?ldflags} -lpython%{python3_version}"

%make_build
popd

mkdir python3-pyqt4-sip
pushd python3-pyqt4-sip
%{__python3} ../configure.py \
             --sip-module=PyQt4.sip \
             --no-tools \
             CXXFLAGS+="%{optflags}" \
             CFLAGS+="%{optflags}" \
             LFLAGS+="%{ldflags}" \
             LIBS="%{?ldflags} -lpython%{python3_version}"

%make_build
popd

mkdir python3-pyqt5-sip
pushd python3-pyqt5-sip
%{__python3} ../configure.py \
             --sip-module=PyQt5.sip \
             --no-tools \
             CXXFLAGS+="%{optflags}" \
             CFLAGS+="%{optflags}" \
             LFLAGS+="%{ldflags}" \
             LIBS="%{?ldflags} -lpython%{python3_version}"

%make_build
popd

sed -i -e 's|target = sip|target = siplib|g' siplib/siplib.sbf
mkdir python3-wx-siplib
pushd python3-wx-siplib
%{__python3} ../configure.py \
             --sip-module=wx.siplib \
             --no-tools \
             CXXFLAGS+="%{optflags}" \
             CFLAGS+="%{optflags}" \
             LFLAGS+="%{ldflags}" \
             LIBS="%{?ldflags} -lpython%{python3_version}"

%make_build
popd
sed -i -e 's|target = siplib|target = sip|g' siplib/siplib.sbf


%install
### Python3 ###
%make_install -C python3-sip
mkdir -p %{buildroot}%{_datadir}/python3-sip
mv %{buildroot}%{_bindir}/sip %{buildroot}%{_bindir}/python3-sip
ln -s python3-sip %{buildroot}%{_bindir}/sip
%make_install -C python3-pyqt4-sip
%make_install -C python3-pyqt5-sip
%make_install -C python3-wx-siplib
mv %{buildroot}%{python3_sitearch}/wx/sip.pyi %{buildroot}%{python3_sitearch}/wx/siplib.pyi

# in sip package
rm -f %buildroot/%{_bindir}/sip
rm -f %buildroot/%{_bindir}/python3-sip
rm -f %buildroot/%{_bindir}/sip-pyqt4
rm -f %buildroot/%{_bindir}/sip-pyqt5
rm -f %buildroot/%{_bindir}/sip-wx

%changelog
* Sun Oct 03 2021 tex - 4.19.25-2pclos2021
- try to fix sip mess
